# tan

-----

> 弹出一个世界。
> 开发者快速在 terminal 中打开当前目录，只需要输入 `tan`，提高开发效率。
> 此工具只支持 Python 3.6+。


### 快速安装

1. pip 安装（推荐）

```python
pip install tan_up
```

2. pipenv 安装

```python
pipenv install tan_up
```

3. 源码安装

```
python setup.py install
```

### 快速使用

1. Windows
# TODO

2. Mac
# TODO

### 开源代码

* [pyperclip](https://github.com/asweigart/pyperclip)

* [terminaltables](https://github.com/Robpol86/terminaltables)

* [colorama](https://github.com/tartley/colorama)

### LICENSE
MIT